ams.core.service.NumOpDual
==========================

.. currentmodule:: ams.core.service

.. autoclass:: NumOpDual

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: _generated/

   
       
       
          ~NumOpDual.assign_memory
       
       
          ~NumOpDual.evaluate
       
       
          ~NumOpDual.get_names
       
       
          ~NumOpDual.parse
       
       
          ~NumOpDual.update
       
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
      :toctree: _generated/

   
      ~NumOpDual.class_name
      ~NumOpDual.n
      ~NumOpDual.shape
      ~NumOpDual.size
      ~NumOpDual.v
      ~NumOpDual.v0
      ~NumOpDual.v1
   
   